@@ -3,14 +3,10 @@ cclib (http://cclib.sf.net) is (c) 2006, the cclib development team
 and licensed under the LGPL (http://www.gnu.org/copyleft/lgpl.html).
 """
 
-__revision__ = "$Revision: 649 $"
+__revision__ = "$Revision: 748 $"
 
 
-# If numpy is not installed, try to import Numeric instead.
-try:
-    import numpy
-except ImportError:
-    import Numeric as numpy
+import numpy
 
 import utils
 import logfileparser
@@ -106,12 +102,23 @@ class ADF(logfileparser.Logfile):
 
                 self.updateprogress(inputfile, "Unsupported Information", self.fupdate)
 
+                if line.find("INPUT FILE") >=0 and hasattr(self,"scftargets"):
+                #does this file contain multiple calculations?
+                #if so, print a warning and skip to end of file
+                    self.logger.warning("Skipping remaining calculations")
+                    inputfile.seek(0,2)
+                    break
+
                 if line.find("INPUT FILE") >= 0:
                     line2 = inputfile.next()
                 else:
                     line2 = None
 
-                if line2 and line2.find("Create") < 0:
+                if line2 and len(line2) <= 2:
+                #make sure that it's not blank like in the NiCO4 regression
+                    line2 = inputfile.next()
+
+                if line2 and (line2.find("Create") < 0 and line2.find("create") < 0):
                     break
 
                 line = inputfile.next()
@@ -530,6 +537,7 @@ class ADF(logfileparser.Logfile):
         # now that we're here, let's extract aonames
 
             self.fonames = []
+            self.start_indeces = {}
 
             blank = inputfile.next()
             note = inputfile.next()
@@ -545,7 +553,8 @@ class ADF(logfileparser.Logfile):
             self.nosymreps = []
             while len(self.fonames) < self.nbasis:
 
-                sym = inputfile.next()
+                symline = inputfile.next()
+                sym = symline.split()[1]
                 line = inputfile.next()
                 num = int(line.split(':')[1].split()[0])
                 self.nosymreps.append(num)
@@ -560,6 +569,10 @@ class ADF(logfileparser.Logfile):
                     info = line.split()
 
                     #index0 index1 occ2 energy3/4 fragname5 coeff6 orbnum7 orbname8 fragname9
+                    if not sym in self.start_indeces.keys():
+                    #have we already set the start index for this symmetry?
+                        self.start_indeces[sym] = int(info[1])
+
                     orbname = info[8]
                     orbital = info[7] + orbname.replace(":", "")
 
@@ -696,9 +709,16 @@ class ADF(logfileparser.Logfile):
                     # The table can end with a blank line or "1".
                     row = 0
                     while not line.strip() in ["", "1"]:
+                        info = line.split()
+
+                        if int(info[0]) < self.start_indeces[sym]:
+                        #check to make sure we aren't parsing CFs
+                            line = inputfile.next()
+                            continue
+
                         self.updateprogress(inputfile, "Coefficients", self.fupdate)
                         row += 1
-                        coeffs = [float(x) for x in line.split()[1:]]
+                        coeffs = [float(x) for x in info[1:]]
                         moindices = [aolist[n-1] for n in monumbers]
                         # The AO index is 1 less than the row.
                         aoindex = symoffset + row - 1
