@@ -3,16 +3,12 @@ cclib (http://cclib.sf.net) is (c) 2006, the cclib development team
 and licensed under the LGPL (http://www.gnu.org/copyleft/lgpl.html).
 """
 
-__revision__ = "$Revision: 665 $"
+__revision__ = "$Revision: 713 $"
 
 
 import re
 
-# If numpy is not installed, try to import Numeric instead.
-try:
-    import numpy
-except ImportError:
-    import Numeric as numpy
+import numpy
 
 import utils
 import logfileparser
@@ -63,19 +59,14 @@ class GAMESS(logfileparser.Logfile):
     def extract(self, inputfile, line):
         """Extract information from the file object inputfile."""
         
-        if line.find("OPTTOL") >= 0:
-            # Two possibilities:
-            #           OPTTOL = 1.000E-04          RMIN   = 1.500E-03
-            # INPUT CARD> $STATPT OPTTOL=0.0001 NSTEP=100 $END
+        # We are looking for this line:
+        #           PARAMETERS CONTROLLING GEOMETRY SEARCH ARE
+        #           ...
+        #           OPTTOL = 1.000E-04          RMIN   = 1.500E-03
+        if line[10:18] == "OPTTOL =":
             if not hasattr(self, "geotargets"):
-                temp = line.split()
-                for i, x in enumerate(temp):
-                    if x.find("OPTTOL") >= 0:
-                        if x == "OPTTOL":
-                            opttol = float(temp[i + 2])
-                        else:
-                            opttol = float(x.split('=')[1])
-                        self.geotargets = numpy.array([opttol, 3. / opttol], "d")
+                opttol = float(line.split()[2])
+                self.geotargets = numpy.array([opttol, 3. / opttol], "d")
                         
         if line.find("FINAL") == 1:
             if not hasattr(self, "scfenergies"):
@@ -222,11 +213,30 @@ class GAMESS(logfileparser.Logfile):
             strength = float(line.split()[3])
             self.etoscs.append(strength)
 
-        if line.find("MAXIMUM GRADIENT") > 0:
+        # Maximum and RMS gradients.
+        if "MAXIMUM GRADIENT" in line or "RMS GRADIENT" in line:
+
             if not hasattr(self, "geovalues"):
                 self.geovalues = []
-            temp = line.strip().split()
-            self.geovalues.append([float(temp[3]), float(temp[7])])
+
+            parts = line.split()
+
+            # Newer versions (around 2006) have both maximum and RMS on one line:
+            #       MAXIMUM GRADIENT =  0.0531540    RMS GRADIENT = 0.0189223
+            if len(parts) == 8:
+                maximum = float(parts[3])
+                rms = float(parts[7])
+            
+            # In older versions of GAMESS, this spanned two lines, like this:
+            #       MAXIMUM GRADIENT =    0.057578167
+            #           RMS GRADIENT =    0.027589766
+            if len(parts) == 4:
+                maximum = float(parts[3])
+                line = inputfile.next()
+                parts = line.split()
+                rms = float(parts[3])
+
+            self.geovalues.append([maximum, rms])
 
         if line[11:50] == "ATOMIC                      COORDINATES":
             # This is the input orientation, which is the only data available for
@@ -273,25 +283,24 @@ class GAMESS(logfileparser.Logfile):
                 line = inputfile.next()
             self.atomcoords.append(atomcoords)
         
+        # This is the section with the SCF information.
         if line.rstrip()[-15:] == "SCF CALCULATION":
-            # This is the section with the SCF information
+
             line = inputfile.next()
-            while line.find("ITER EX") < 0:
-                if line.find("DENSITY CONV=") >= 0 or line.find("DENSITY MATRIX CONV=") >= 0:
-        # Needs to deal with lines like:
-        # (GAMESS VERSION = 12 DEC 2003)
-        #     DENSITY MATRIX CONV=  2.00E-05  DFT GRID SWITCH THRESHOLD=  3.00E-04
-        # (GAMESS VERSION = 22 FEB 2006)
-        #           DENSITY MATRIX CONV=  1.00E-05
-        # (PC GAMESS version 6.2, Not DFT?)
-        #     DENSITY CONV=  1.00E-05
-                    index = line.find("DENSITY CONV=")
-                    if index < 0:
-                        index = line.find("DENSITY MATRIX CONV=")
-                        index += len("DENSITY MATRIX CONV=")
-                    else:
-                        index += len("DENSITY CONV=")
-                    scftarget = float(line[index:].split()[0])
+
+            while not "ITER EX" in line:
+
+                # Deal with the various versions:
+                #   (GAMESS VERSION = 12 DEC 2003)
+                #     DENSITY MATRIX CONV=  2.00E-05  DFT GRID SWITCH THRESHOLD=  3.00E-04
+                #   (GAMESS VERSION = 22 FEB 2006)
+                #     DENSITY MATRIX CONV=  1.00E-05
+                #   (PC GAMESS version 6.2, Not DFT?)
+                #     DENSITY CONV=  1.00E-05
+                if "DENSITY CONV" in line or "DENSITY MATRIX CONV" in line:
+
+                    scftarget = float(line.split()[-1])
+
                 line = inputfile.next()
 
             if not hasattr(self, "scftargets"):
@@ -553,12 +562,20 @@ class GAMESS(logfileparser.Logfile):
 
             dashes = inputfile.next()
             for base in range(0, self.nmo, 5):
-                blank = inputfile.next()
-                line = inputfile.next() # Eigenvector numbers.
-                line = inputfile.next() # Eigenvalues for these orbitals (in hartrees).
+
+                line = inputfile.next()
+                numbers = inputfile.next() # Eigenvector numbers.
+
+                # Eigenvalues for these orbitals (in hartrees).
+                # Sometimes there are some blank lines before it.
+                while not line.strip():
+                    line = inputfile.next()
                 self.moenergies[0].extend([utils.convertor(float(x), "hartree", "eV") for x in line.split()])
-                line = inputfile.next() # Orbital symmetries.
-                self.mosyms[0].extend(map(self.normalisesym, line.split()))
+
+                # Orbital symmetries.
+                line = inputfile.next()
+                if line.strip():
+                    self.mosyms[0].extend(map(self.normalisesym, line.split()))
                 
                 # Now we have nbasis lines.
                 # Going to use the same method as for normalise_aonames()
@@ -592,10 +609,11 @@ class GAMESS(logfileparser.Logfile):
                         j += 1
 
             line = inputfile.next()
-            # If it's restricted we have:
-            #  ...... END OF RHF CALCULATION ......
-            #                or
-            #  ...... END OF DFT CALCULATION ......
+            # If it's restricted and no more properties:
+            #  ...... END OF RHF/DFT CALCULATION ......
+            # If there are more properties (DENSITY MATRIX):
+            #               --------------
+            #
             # If it's unrestricted we have:
             #
             #  ----- BETA SET ----- 
@@ -606,11 +624,12 @@ class GAMESS(logfileparser.Logfile):
             #
             #                      1          2          3          4          5
             # ... and so forth.
-            if not "END OF" in line:
+            line = inputfile.next()
+            if line[2:22] == "----- BETA SET -----":
                 self.mocoeffs.append(numpy.zeros((self.nmo, self.nbasis), "d"))
                 self.moenergies.append([])
                 self.mosyms.append([])
-                for i in range(5):
+                for i in range(4):
                     line = inputfile.next()
                 for base in range(0, self.nmo, 5):
                     blank = inputfile.next()
@@ -627,9 +646,40 @@ class GAMESS(logfileparser.Logfile):
                             self.mocoeffs[1][base+j, i] = float(temp[j * 11:(j + 1) * 11])
                             j += 1
                 line = inputfile.next()
-            assert line.find("END OF") >= 0
             self.moenergies = [numpy.array(x, "d") for x in self.moenergies]
 
+        # Natural orbitals - presently support only CIS.
+        # Looks basically the same as eigenvectors, without symmetry labels.
+        if line[10:30] == "CIS NATURAL ORBITALS":
+
+            self.nocoeffs = numpy.zeros((self.nmo, self.nbasis), "d")
+
+            dashes = inputfile.next()
+            for base in range(0, self.nmo, 5):
+
+                blank = inputfile.next()
+                numbers = inputfile.next() # Eigenvector numbers.
+
+                # Eigenvalues for these natural orbitals (not in hartrees!).
+                # Sometimes there are some blank lines before it.
+                line = inputfile.next()
+                while not line.strip():
+                    line = inputfile.next()
+                eigenvalues = line
+
+                # Orbital symemtry labels are normally here for MO coefficients.
+                line = inputfile.next()
+                
+                # Now we have nbasis lines with the coefficients.
+                for i in range(self.nbasis):
+
+                    line = inputfile.next()
+                    coeffs = line[15:]
+                    j = 0
+                    while j*11+4 < len(coeffs):
+                        self.nocoeffs[base+j, i] = float(coeffs[j * 11:(j + 1) * 11])
+                        j += 1
+
         if line.find("NUMBER OF OCCUPIED ORBITALS") >= 0:
             homos = [int(line.split()[-1])-1]
             line = inputfile.next()
