@@ -3,16 +3,12 @@ cclib (http://cclib.sf.net) is (c) 2006, the cclib development team
 and licensed under the LGPL (http://www.gnu.org/copyleft/lgpl.html).
 """
 
-__revision__ = "$Revision: 657 $"
+__revision__ = "$Revision: 717 $"
 
 
 import re
 
-# If numpy is not installed, try to import Numeric instead.
-try:
-    import numpy
-except ImportError:
-    import Numeric as numpy
+import numpy
 
 import utils
 import logfileparser
@@ -179,7 +175,8 @@ class GAMESSUK(logfileparser.Logfile):
 
             minus = inputfile.next()
             blank = inputfile.next()
-            for i in range(0,self.nbasis,12):
+            i = 0
+            while i < self.nbasis:
                 blank = inputfile.next()
                 blank = inputfile.next()
                 header = inputfile.next()
@@ -189,6 +186,8 @@ class GAMESSUK(logfileparser.Logfile):
                 for j in range(self.nbasis):
                     temp = map(float, inputfile.next().split()[1:])
                     self.aooverlaps[j,(0+i):(len(temp)+i)] = temp
+                    
+                i += len(temp)
 
         if line[18:43] == 'EFFECTIVE CORE POTENTIALS':
             self.coreelectrons = numpy.zeros(self.natom, 'i')
