@@ -3,16 +3,12 @@ cclib (http://cclib.sf.net) is (c) 2006, the cclib development team
 and licensed under the LGPL (http://www.gnu.org/copyleft/lgpl.html).
 """
 
-__revision__ = "$Revision: 635 $"
+__revision__ = "$Revision: 709 $"
 
 
 import re
 
-# If numpy is not installed, try to import Numeric instead.
-try:
-    import numpy
-except ImportError:
-    import Numeric as numpy
+import numpy
 
 import utils
 import logfileparser
