@@ -3,12 +3,12 @@
 
 import os
 
-def folder(screen,logfile):
+def folder(screen,logfilename):
      # Create the output directory if necessary
      
-    logdir=os.path.dirname(logfile.filename)
-    logname=os.path.basename(logfile.filename)
-    gaussdir=os.path.join(logdir,"gausssum2.0")
+    logdir=os.path.dirname(logfilename)
+    logname=os.path.basename(logfilename)
+    gaussdir=os.path.join(logdir,"gausssum2.1")
     if not os.path.isdir(gaussdir):
         screen.write("Creating new output folder\n")
         os.mkdir(gaussdir)
