@@ -372,25 +372,23 @@ class App:    # This sets up the GUI
         try:
             if s=="SCF":
                 if self.reparse.get():
-                    self.logfile.clean()
-                    self.logfile.parse()
-                worked = SCF(self.root,self.screen,self.logfile,int(self.numpts.get()),self.settings['global settings.gnuplot'])
+                    self.data = self.logfile.parse()
+                worked = SCF(self.root,self.screen,self.data,int(self.numpts.get()),self.settings['global settings.gnuplot'])
             elif s=="GEOOPT":
                 if self.reparse.get():
-                    self.logfile.clean()
-                    self.logfile.parse()
-                worked = GeoOpt(self.root,self.screen,self.logfile,int(self.numpts.get()),self.settings['global settings.gnuplot'])                
+                    data = self.logfile.parse()
+                worked = GeoOpt(self.root,self.screen,self.data,int(self.numpts.get()),self.settings['global settings.gnuplot'])                
             elif s=="IR_RAMAN":
-                worked = Vibfreq(self.root,self.screen,self.logfile,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.scale.get(),float(self.scalefactor.get()),self.settings['global settings.gnuplot'])
+                worked = Vibfreq(self.root,self.screen,self.data,self.logfile.filename,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.scale.get(),float(self.scalefactor.get()),self.settings['global settings.gnuplot'])
             elif s=="FIND":
                 if self.searchrad.get()=="Custom":
-                    worked = Search(self.screen,self.logfile,self.customsearch.get(),self.casesensitive.get())
+                    worked = Search(self.screen,self.logfile.filename,self.customsearch.get(),self.casesensitive.get())
                 else:
-                    worked = Search(self.screen,self.logfile,self.searchrad.get(),1)
+                    worked = Search(self.screen,self.logfile.filename,self.searchrad.get(),1)
             elif s=="MO":
-                worked = Popanalysis(self.root,self.screen,self.logfile,float(self.start.get()),float(self.end.get()),self.MOplot.get(),float(self.FWHM.get()),self.makeorigin.get(),self.settings['global settings.gnuplot'])
+                worked = Popanalysis(self.root,self.screen,self.data,self.logfile.filename,float(self.start.get()),float(self.end.get()),self.MOplot.get(),float(self.FWHM.get()),self.makeorigin.get(),self.settings['global settings.gnuplot'])
             elif s=="UVVIS":
-                worked = ET(self.root,self.screen,self.logfile,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.UVplot.get(),self.settings['global settings.gnuplot'])
+                worked = ET(self.root,self.screen,self.data,self.logfile.filename,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.UVplot.get(),self.settings['global settings.gnuplot'])
 ##            elif s=="EDDM":
 ##                worked=GaussSum.EDDM.EDDM(self.screen,self.logfile,self.trans.get(),self.settings['eddm.cubman'],self.settings['eddm.formchk'],self.settings['eddm.cubegen'])
 ##            elif s=="NMR":
@@ -488,7 +486,7 @@ class App:    # This sets up the GUI
         self.logfile.logger.addHandler(newhandler)
         
         try:
-            self.logfile.parse()
+            self.data = self.logfile.parse()
         except:
             tkMessageBox.showerror(
                 title="Problems parsing the logfile",
@@ -501,7 +499,7 @@ class App:    # This sets up the GUI
             return
         
         self.screen.write("Opened and parsed %s.\n" % self.inputfilename)
-        has = lambda x: hasattr(self.logfile, x)
+        has = lambda x: hasattr(self.data, x)
         self.b3.configure(state=NORMAL) # Search
         if has("scftargets") and has("scfvalues"):
             self.b0.configure(state=NORMAL)
@@ -535,13 +533,13 @@ class App:    # This sets up the GUI
     def saveprefs(self):
         # Save the settings
         appdata=os.getenv("HOME")
-        settingsfile=os.path.join(appdata,".GaussSum2.0","GaussSum.ini")
+        settingsfile=os.path.join(appdata,"GaussSum2.1","GaussSum.ini")
         writeoutconfigfile(self.settings,settingsfile)
 
 
     def readprefs(self):
-        # Check for GaussSum.ini in $HOME/GaussSum2.0 (XP)
-        #                        or $HOME/.gausssum2.0 (Linux)
+        # Check for GaussSum.ini in $HOME/GaussSum2.1 (XP)
+        #                        or $HOME/.gausssum2.1 (Linux)
 
         appdata=os.getenv("HOME")
         self.settings={}
@@ -551,7 +549,7 @@ class App:    # This sets up the GUI
                                I cannot continue, as I need HOME to know\
                                where to store GaussSum settings.\n")
         else: # If everything is normal so far
-            settingsdir=os.path.join(appdata,".GaussSum2.0")
+            settingsdir=os.path.join(appdata,"GaussSum2.1")
             settingsfile=os.path.join(settingsdir,"GaussSum.ini")
 
             if os.path.isfile(settingsfile): # Check for settings file
