@@ -1,10 +1,10 @@
-def Search(screen,logfile,searchstring,case_sensitive):
+def Search(screen, logfilename, searchstring, case_sensitive):
 
     screen.write("Starting to search\n")
 
     searchterm = searchstring.split("%")
 
-    inputfile = open(logfile.filename, "r")
+    inputfile = open(logfilename, "r")
 
     if not case_sensitive:
         # change all the searchterms to lowercase
@@ -23,7 +23,8 @@ def Search(screen,logfile,searchstring,case_sensitive):
             if searchline.find(x) >= 0:
                 screenoutput.append(line)
                 break
-
+    inputfile.close()
+    
     screen.write("".join(screenoutput))
 
     screen.write("Finished searching\n")
